@@ -47,7 +47,6 @@ class ImageWindowSignals(PyQt5.QtCore.QObject):
     """
     """
     __all__ = ['ImageWindowSignals']
-    showCurrent = PyQt5.QtCore.pyqtSignal()
     solveImage = PyQt5.QtCore.pyqtSignal(object)
 
 
@@ -67,7 +66,6 @@ class ImageWindow(toolsQtWidget.MWidget):
 
         self.imageFileName = ''
         self.imageFileNameOld = ''
-        self.preparePlotLock = QMutex()
         self.expTime = 1
         self.binning = 1
         self.image = None
@@ -208,7 +206,6 @@ class ImageWindow(toolsQtWidget.MWidget):
         self.ui.checkStackImages.clicked.connect(self.clearStack)
         self.ui.abortImage.clicked.connect(self.abortImage)
         self.ui.abortSolve.clicked.connect(self.abortSolve)
-        self.signals.showCurrent.connect(self.showCurrent)
         self.signals.solveImage.connect(self.solveImage)
         self.app.showImage.connect(self.showImage)
         self.show()
@@ -240,7 +237,6 @@ class ImageWindow(toolsQtWidget.MWidget):
         self.ui.checkStackImages.clicked.disconnect(self.clearStack)
         self.ui.abortImage.clicked.disconnect(self.abortImage)
         self.ui.abortSolve.clicked.disconnect(self.abortSolve)
-        self.signals.showCurrent.disconnect(self.showCurrent)
         self.signals.solveImage.disconnect(self.solveImage)
         self.app.showImage.disconnect(self.showImage)
         plt.close(self.imageMat.figure)
@@ -280,12 +276,10 @@ class ImageWindow(toolsQtWidget.MWidget):
             self.ui.exposeN.setEnabled(False)
             self.ui.load.setEnabled(False)
             self.ui.abortImage.setEnabled(True)
-
         elif self.deviceStat['exposeN']:
             self.ui.expose.setEnabled(False)
             self.ui.load.setEnabled(False)
             self.ui.abortImage.setEnabled(True)
-
         else:
             self.ui.solve.setEnabled(True)
             self.ui.expose.setEnabled(True)
@@ -295,7 +289,6 @@ class ImageWindow(toolsQtWidget.MWidget):
 
         if self.deviceStat['solve']:
             self.ui.abortSolve.setEnabled(True)
-
         else:
             self.ui.abortSolve.setEnabled(False)
 
@@ -308,19 +301,17 @@ class ImageWindow(toolsQtWidget.MWidget):
 
         if self.deviceStat['expose']:
             self.changeStyleDynamic(self.ui.expose, 'running', 'true')
-
         elif self.deviceStat['exposeN']:
             self.changeStyleDynamic(self.ui.exposeN, 'running', 'true')
-
         else:
             self.changeStyleDynamic(self.ui.expose, 'running', 'false')
             self.changeStyleDynamic(self.ui.exposeN, 'running', 'false')
 
         if self.deviceStat['solve']:
             self.changeStyleDynamic(self.ui.solve, 'running', 'true')
-
         else:
             self.changeStyleDynamic(self.ui.solve, 'running', 'false')
+
         return True
 
     def selectImage(self):
@@ -633,14 +624,6 @@ class ImageWindow(toolsQtWidget.MWidget):
         """
         :return:
         """
-        if self.image is None:
-            self.preparePlotLock.unlock()
-            return False
-
-        if self.header is None:
-            self.preparePlotLock.unlock()
-            return False
-
         self.updateWindowsStats()
         if 'CTYPE1' in self.header:
             wcsObject = wcs.WCS(self.header, relax=True)
@@ -660,7 +643,6 @@ class ImageWindow(toolsQtWidget.MWidget):
 
         if hasDistortion and useWCS and canWCS:
             self.setupDistorted()
-
         else:
             self.setupNormal()
 
@@ -668,15 +650,12 @@ class ImageWindow(toolsQtWidget.MWidget):
         self.stretchImage()
         self.colorImage()
         self.imagePlot()
-        self.preparePlotLock.unlock()
         return True
 
     def preparePlot(self):
         """
         :return:
         """
-        if not self.preparePlotLock.tryLock():
-            return False
         worker = Worker(self.workerPreparePlot)
         self.threadPool.start(worker)
         return True
@@ -713,8 +692,9 @@ class ImageWindow(toolsQtWidget.MWidget):
             worker = Worker(self.workerPhotometry)
             worker.signals.finished.connect(self.preparePlot)
             self.threadPool.start(worker)
+        else:
+            self.preparePlot()
 
-        self.preparePlot()
         return True
 
     def stackImages(self):
@@ -732,7 +712,6 @@ class ImageWindow(toolsQtWidget.MWidget):
         if self.imageStack is None:
             self.imageStack = self.image
             self.numberStack = 1
-
         else:
             self.imageStack = np.add(self.imageStack, self.image)
             self.numberStack += 1
@@ -790,10 +769,8 @@ class ImageWindow(toolsQtWidget.MWidget):
         :param imagePath:
         :return:
         """
-        import time
         if not imagePath:
             return False
-
         if not os.path.isfile(imagePath):
             return False
 
@@ -804,10 +781,9 @@ class ImageWindow(toolsQtWidget.MWidget):
         with fits.open(imagePath, mode='update') as fitsHandle:
             self.image = fitsHandle[0].data
             self.header = fitsHandle[0].header
-
-        if self.image is None:
+            
+        if self.image is None or self.image == []:
             return False
-
         if self.header is None:
             return False
 
@@ -851,7 +827,6 @@ class ImageWindow(toolsQtWidget.MWidget):
         focalLength = self.app.telescope.focalLength
 
         self.imageFileNameOld = self.imageFileName
-
         self.app.camera.expose(imagePath=imagePath,
                                expTime=self.expTime,
                                binning=self.binning,
@@ -873,7 +848,6 @@ class ImageWindow(toolsQtWidget.MWidget):
         :param imagePath:
         :return: True for test purpose
         """
-
         self.deviceStat['expose'] = False
         self.app.camera.signals.saved.disconnect(self.exposeImageDone)
         text = f'Exposed:             [{os.path.basename(imagePath)}]'
@@ -881,7 +855,6 @@ class ImageWindow(toolsQtWidget.MWidget):
 
         if self.ui.checkAutoSolve.isChecked():
             self.signals.solveImage.emit(imagePath)
-
         else:
             self.app.showImage.emit(imagePath)
 
@@ -911,7 +884,6 @@ class ImageWindow(toolsQtWidget.MWidget):
 
         if self.ui.checkAutoSolve.isChecked():
             self.signals.solveImage.emit(imagePath)
-
         else:
             self.app.showImage.emit(imagePath)
 
